<?php
/*
  $Id: popup_search_help.php,v 1.4 2006/07/16 05:09:33 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
*/

  require('includes/application_top.php');

  $navigation->remove_current_page();

  require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_ADVANCED_SEARCH);
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html <?php echo HTML_PARAMS; ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
<meta http-equiv="content-style-type" content="text/css" />
<title><?php echo TITLE; ?></title>
<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
<link rel="stylesheet" type="text/css" href="popup_search_help.css" media="screen,print" />
</head>
<body>
<div id="popupSearchHelp">
<?php
  $cssid = 'popupSearchHelp';
  $contentbox_header = HEADING_SEARCH_HELP;
  $contentbox_footer = '<a href="javascript:window.close()">' . TEXT_CLOSE_WINDOW . '</a>';

  $contentbox_contents = array();
  $contentbox_contents[] = array('text' => TEXT_SEARCH_HELP);

  new contentBox($cssid, $contentbox_contents, $contentbox_header, $contentbox_footer);
?>
</div>
</body>
</html>
<?php require('includes/application_bottom.php'); ?>
